#
# spec file for package xfce4-timer-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin timer
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.7.2
Release:        1.3
Summary:        Alarm Clock Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-timer-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.7/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.26.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.26.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Timer plugin provides the functionality of an alarm clock and will run an
alarm at a specified time or at the end of a specified countdown period.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install
rm -fv %{buildroot}%{_libdir}/xfce4/panel/plugins/*.la

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md TODO
%license COPYING
%{_libdir}/xfce4/panel/plugins/libxfcetimer.so
%{_datadir}/icons/hicolor/*/*/xfce4-timer-plugin.*
%{_datadir}/xfce4/panel/plugins/xfce4-timer-plugin.desktop

%files lang -f %{name}.lang

%changelog
* Tue Apr 18 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.7.2
  * Update copyright year and bug report address
  * always keep the dialog window above
  * Allow to start any timer on timeout
  * Remove dead code generating a warning
  * Remove wrong function call
  * Do not quit the main loop on "free-data"
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Update configure.ac.in
  * Use "logo-icon-name" instead of "logo" in about dialog
  * build: Fix intltool lock file problem during make distcheck
  * Update COPYING
  * Delete "xfce4" from various strings
  * Replace GTimeVal with GDateTime
  * Context menu option to add new timer and pause/stop icons (!11)
  * Fix missing translation macro for Time's up dialog
  * Fix compilation warnings
  * autoconf: Some updates
  * Update `.gitignore`
  * Request automatic widget length
  * Properly save settings for many plugin instances
  * Reaplce AC_CONFIG_MACRO_DIR with AC_CONFIG_MACRO_DIRS (!1)
  * Create README.md. Update configure.ac.in
  * Translation Updates
- Remove _service file
* Fri Jul 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.7.1
  * Update URLs from goodies.x.o to docs.x.o (bxo#16180)
  * Do not recreate box when orientation changes
  * Remove unused eventbox
  * Avoid square-sized plugin (bxo#16101)
  * Remove unused variables and function
  * Resolve GCC warning: ISO C90 forbids mixed declarations and code
  * Preferences: Improved spacing and layout in editor (bxo#14678)
  * Selecting a timer always starts it
  * Add Hossam Ayman's multiple timer code, some leak and g_free
    fixes in update_function.
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed source in spec file
* Mon Jul 29 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Use %%license for COPYING
- Added bcond for git master builds
* Sat Feb 17 2018 seife+obs@b1-systems.com
- update to version 1.7.0
  * port to GTK+3
  * new icon (bxo #13517)
  * add "keep above" for Beep dialog (bxo#13514)
  * when paused show all menu timers (bxo#13516)
  * small UI improvements (bxo#13515)
  * translation updates
- package NEWS file instead of huge ChangeLog
* Thu Jun  5 2014 gber@opensuse.org
- update to version 1.6.0
  - added button in the alarm window to rerun the timer
  - minor fixes and code cleanup
* Fri May 10 2013 gber@opensuse.org
- update to version 1.5.0
  - major code reorganization
  - allow popup menuitems to be activated by keyboard
  - various minor bugfixes
  - add the "About" dialog
* Tue Apr 23 2013 gber@opensuse.org
- update to version 1.0.2
  - some code cleanup
  - now the alarm dialog window displays the alarm name
  - added the option to define a default alarm command
* Wed Sep  5 2012 gber@opensuse.org
- update to version 1.0.0
  - fix a crash with 4.8+ panels
  - fix a segfault when the timer is paused
  - fix border sizes
  - code cleanups and introduce the optional feature "selecting a
    timer starts it"
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Tue Feb  7 2012 gber@opensuse.org
- update to version 0.6.4
  - incorporated xfce4-panel-plugin-timer-fix-windows.patch and
    xfce4-panel-plugin-timer-fix-timerinfo-truncation.patch
  - the mouse click receive code is separated for pre-4.8 and 4.8
    panels
  - added an icon
* Thu Feb  2 2012 gber@opensuse.org
- added xfce4-panel-plugin-timer-fix-windows.patch in order to set
  the add/edit dialog transient for the main configuration window
  and to make the notification dialog modal
* Thu Jan 26 2012 gber@opensuse.org
- added xfce4-panel-plugin-timer-fix-timerinfo-truncation.patch
  which uses a dynamically allocated string to hold timer data in
  order to prevent truncation in some locales (bnc#742788)
* Thu Jan  5 2012 gber@opensuse.org
- update to version 0.6.3
  - translation updates
* Sun Jun 19 2011 gber@opensuse.org
- update to version 0.6.2
  - added pause/resume functionality
  - minor fixes and cleanup
  - translation updates
- dropped
  xfce4-panel-plugin-timer-0.6.1-fix-invalid-function-type.patch
  which has been applied upstream
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
